.. py:currentmodule:: asyncakinator


asyncakinator
=============

An async API wrapper for the online game, Akinator, written in Python.

.. toctree::
    :caption: Getting Started

    pages/introduction
    pages/examples


.. toctree::
    :caption: API Reference

    pages/api_reference
